@@ -15,6 +15,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ * 
  */
 
 #include <sys/types.h>
@@ -156,8 +164,7 @@ bacon_message_connection_new (const char *prefix)
 	g_return_val_if_fail (prefix != NULL, NULL);
 
 	filename = g_strdup_printf (".%s.%s", prefix, g_get_user_name ());
-	path = g_build_filename (G_DIR_SEPARATOR_S, g_get_home_dir (),
-			filename, NULL);
+	path = g_build_filename (g_get_home_dir (), filename, NULL);
 	g_free (filename);
 
 	conn = g_new0 (BaconMessageConnection, 1);
@@ -200,7 +207,7 @@ bacon_message_connection_free (BaconMessageConnection *conn)
 	g_return_if_fail (conn != NULL);
 	g_return_if_fail (conn->path != NULL);
 
-	if (conn->is_server == TRUE)
+	if (conn->is_server != FALSE)
 	{
 		g_io_channel_shutdown (conn->chan, FALSE, NULL);
 		g_io_channel_unref (conn->chan);
@@ -219,7 +226,7 @@ bacon_message_connection_set_callback (BaconMessageConnection *conn,
 				       gpointer user_data)
 {
 	g_return_if_fail (conn != NULL);
-	g_assert (conn->is_server == TRUE);
+	g_assert (conn->is_server != FALSE);
 
 	g_io_add_watch (conn->chan, G_IO_IN, server_cb, conn);
 
