@@ -1,6 +1,5 @@
-/* 
- * Copyright (C) 2001-2002 the xine project
- * 	Heavily modified by Bastien Nocera <hadess@hadess.net>
+/*
+ * Copyright (C) 2001,2002,2003,2004,2005 Bastien Nocera <hadess@hadess.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,9 +15,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.53 2004/12/30 20:25:33 hadess Exp $
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
  *
- * the xine engine in a widget - header
  */
 
 #ifndef HAVE_BACON_VIDEO_WIDGET_H
@@ -93,6 +97,8 @@ typedef enum {
 GQuark bacon_video_widget_error_quark		 (void) G_GNUC_CONST;
 GType bacon_video_widget_get_type                (void);
 struct poptOption *bacon_video_widget_get_popt_table    (void);
+/* This can be used if the app does not use popt */
+void bacon_video_widget_init_backend		 (int *argc, char ***argv);
 
 typedef enum {
 	BVW_USE_TYPE_VIDEO,
@@ -108,8 +114,10 @@ GtkWidget *bacon_video_widget_new		 (int width, int height,
 char *bacon_video_widget_get_backend_name (BaconVideoWidget *bvw);
 
 /* Actions */
-gboolean bacon_video_widget_open		 (BaconVideoWidget *bvw,
+#define bacon_video_widget_open(bvw, mrl, error) bacon_video_widget_open_with_subtitle(bvw, mrl, NULL, error)
+gboolean bacon_video_widget_open_with_subtitle	 (BaconVideoWidget *bvw,
 						  const char *mrl,
+						  const char *subtitle_uri,
 						  GError **error);
 gboolean bacon_video_widget_play                 (BaconVideoWidget *bvw,
 						  GError **error);
@@ -319,7 +327,7 @@ typedef enum {
 
 BaconVideoWidgetAudioOutType bacon_video_widget_get_audio_out_type
 						 (BaconVideoWidget *bvw);
-void bacon_video_widget_set_audio_out_type       (BaconVideoWidget *bvw,
+gboolean bacon_video_widget_set_audio_out_type   (BaconVideoWidget *bvw,
 						  BaconVideoWidgetAudioOutType
 						  type);
 
