@@ -771,6 +771,7 @@ totem_playlist_remove_files (GtkWidget *widget, TotemPlaylist *playlist)
 			} else {
 				playlist->_priv->current = cur;
 			}
+			g_free (str);
 		} else {
 			playlist->_priv->current = NULL;
 		}
@@ -1310,11 +1311,24 @@ update_shuffle_cb (GConfClient *client, guint cnxn_id,
 			shuffle, NULL);
 }
 
+static void
+update_lockdown (GConfClient *client, guint cnxn_id,
+		GConfEntry *entry, TotemPlaylist *playlist)
+{
+	GtkWidget *button;
+	gboolean locked;
+
+	locked = gconf_client_get_bool (playlist->_priv->gc,
+			"/desktop/gnome/lockdown/disable_save_to_disk", NULL);
+	button = glade_xml_get_widget (playlist->_priv->xml, "save_button");
+	gtk_widget_set_sensitive (button, !locked);
+}
+
 static void
 init_config (TotemPlaylist *playlist)
 {
 	GtkWidget *button;
-	gboolean repeat, shuffle;
+	gboolean repeat, shuffle, locked;
 
 	playlist->_priv->gc = gconf_client_get_default ();
 
@@ -1334,6 +1348,11 @@ init_config (TotemPlaylist *playlist)
 			G_CALLBACK (shuffle_button_toggled),
 			(gpointer) playlist);
 
+	locked = gconf_client_get_bool (playlist->_priv->gc,
+			"/desktop/gnome/lockdown/disable_save_to_disk", NULL);
+	button = glade_xml_get_widget (playlist->_priv->xml, "save_button");
+	gtk_widget_set_sensitive (button, !locked);
+
 	gconf_client_add_dir (playlist->_priv->gc, GCONF_PREFIX,
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_notify_add (playlist->_priv->gc, GCONF_PREFIX"/repeat",
@@ -1343,6 +1362,13 @@ init_config (TotemPlaylist *playlist)
 			(GConfClientNotifyFunc) update_shuffle_cb,
 			playlist, NULL, NULL);
 
+	gconf_client_add_dir (playlist->_priv->gc, "/desktop/gnome/lockdown",
+			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	gconf_client_notify_add (playlist->_priv->gc,
+			"/desktop/gnome/lockdown/disable_save_to_disk",
+			(GConfClientNotifyFunc) update_lockdown,
+			playlist, NULL, NULL);
+
 	playlist->_priv->repeat = repeat;
 	playlist->_priv->shuffle = shuffle;
 }
@@ -1472,7 +1498,7 @@ totem_playlist_new (void)
 	playlist = TOTEM_PLAYLIST (g_object_new (GTK_TYPE_PLAYLIST, NULL));
 
 	playlist->_priv->xml = totem_interface_load ("playlist.glade",
-			"playlist", TRUE, NULL);
+			_("playlist"), TRUE, NULL);
 
 	if (playlist->_priv->xml == NULL)
 	{
