@@ -1,3 +1,4 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* 
  * Copyright (C) 2001,2002,2003 Bastien Nocera <hadess@hadess.net>
  *
@@ -15,15 +16,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ *
  */
 
 #include <config.h>
 #include <gtk/gtkmessagedialog.h>
+#include <glib/gi18n.h>
 #include <string.h>
 #include <stdio.h>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <bacon-cd-selection.h>
+#include <nautilus-burn-drive-selection.h>
 
 #include "totem.h"
 #include "totem-private.h"
@@ -62,12 +73,6 @@ totem_action_info (char *reason, Totem *totem)
 	gtk_widget_show (error_dialog);
 }
 
-static void
-hide_prefs (GtkWidget *widget, int trash, Totem *totem)
-{
-	gtk_widget_hide (totem->prefs);
-}
-
 static gboolean
 ask_show_visuals (Totem *totem)
 {
@@ -79,9 +84,11 @@ ask_show_visuals (Totem *totem)
 				GTK_DIALOG_MODAL,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_YES_NO,
-				_("It seems you are running Totem remotely.\n"
-				"Are you sure you want to enable the visual "
-				"effects?"));
+				_("Enable visual effects?"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  _("It seems you are running Totem remotely.\n"
+						    "Are you sure you want to enable the visual "
+						    "effects?"));
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 			GTK_RESPONSE_NO);
@@ -114,12 +121,12 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
 	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_label");
 	gtk_widget_set_sensitive (item, value);
 	item = glade_xml_get_widget (totem->xml,
-			"tpw_visuals_type_optionmenu");
+			"tpw_visuals_type_combobox");
 	gtk_widget_set_sensitive (item, value);
 	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_label");
 	gtk_widget_set_sensitive (item, value);
 	item = glade_xml_get_widget (totem->xml,
-			"tpw_visuals_size_optionmenu");
+			"tpw_visuals_size_combobox");
 	gtk_widget_set_sensitive (item, value);
 
 	if (warn == FALSE)
@@ -134,7 +141,7 @@ totem_prefs_set_show_visuals (Totem *totem, gboolean value, gboolean warn)
 	{
 		totem_action_info (_("The change of this setting will only "
 					"take effect for the next movie, or "
-					"when Totem is restarted"),
+					"when Totem is restarted."),
 				totem);
 	}
 }
@@ -209,11 +216,14 @@ deinterlace_changed_cb (GConfClient *client, guint cnxn_id,
 }
 
 static void
-on_combo_entry1_changed (BaconCdSelection *bcs, char *device, Totem *totem)
+on_combo_entry1_changed (NautilusBurnDriveSelection *bcs, char *device, Totem *totem)
 {
 	const char *str;
 
-	str = bacon_cd_selection_get_device (bcs);
+	str = nautilus_burn_drive_selection_get_device (bcs);
+	if (str == NULL)
+		str = "";
+
 	gconf_client_set_string (totem->gc, GCONF_PREFIX"/mediadev", str, NULL);
 	bacon_video_widget_set_media_device
 		(BACON_VIDEO_WIDGET (totem->bvw), str);
@@ -255,6 +265,20 @@ show_vfx_changed_cb (GConfClient *client, guint cnxn_id,
 			G_CALLBACK (on_checkbutton2_toggled), totem);
 }
 
+static void
+disable_save_to_disk_changed_cb (GConfClient *client, guint cnxn_id,
+		GConfEntry *entry, Totem *totem)
+{
+	GtkWidget *item;
+	gboolean locked;
+
+	locked = gconf_client_get_bool (totem->gc,
+			"/desktop/gnome/lockdown/disable_save_to_disk", NULL);
+	item = glade_xml_get_widget (totem->xml,
+			"tmw_take_screenshot_menu_item");
+	gtk_widget_set_sensitive (item, !locked);
+}
+
 static void
 mediadev_changed_cb (GConfClient *client, guint cnxn_id,
 		GConfEntry *entry, Totem *totem)
@@ -272,7 +296,7 @@ mediadev_changed_cb (GConfClient *client, guint cnxn_id,
 	if (mediadev == NULL || strcmp (mediadev, "") == 0)
 		mediadev = g_strdup ("/dev/cdrom");
 
-	bacon_cd_selection_set_device (BACON_CD_SELECTION (item), mediadev);
+	nautilus_burn_drive_selection_set_device (NAUTILUS_BURN_DRIVE_SELECTION (item), mediadev);
 	bacon_video_widget_set_media_device
 		(BACON_VIDEO_WIDGET (totem->bvw), mediadev);
 
@@ -281,11 +305,11 @@ mediadev_changed_cb (GConfClient *client, guint cnxn_id,
 }
 
 static void
-option_menu_connection_changed (GtkOptionMenu *option_menu, Totem *totem)
+connection_combobox_changed (GtkComboBox *combobox, Totem *totem)
 {
 	int i;
 
-	i = gtk_option_menu_get_history (option_menu);
+	i = gtk_combo_box_get_active (combobox);
 	bacon_video_widget_set_connection_speed
 		(BACON_VIDEO_WIDGET (totem->bvw), i);
 }
@@ -317,14 +341,14 @@ on_button1_clicked (GtkButton *button, Totem *totem)
 }
 
 static void
-visual_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
+visual_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	GList *list;
 	const char *old_name;
 	char *name;
 	int i;
 
-	i = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
+	i = gtk_combo_box_get_active (combobox);
 	list = bacon_video_widget_get_visuals_list (totem->bvw);
 	name = g_list_nth_data (list, i);
 
@@ -342,11 +366,11 @@ visual_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
 }
 
 static void
-visual_quality_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
+visual_quality_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	int i;
 
-	i = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
+	i = gtk_combo_box_get_active (combobox);
 	gconf_client_set_int (totem->gc,
 			GCONF_PREFIX"/visual_quality", i, NULL);
 	bacon_video_widget_set_visuals_quality (totem->bvw, i);
@@ -357,7 +381,7 @@ bacon_cd_selection_create (void)
 {
 	GtkWidget *widget;
 
-	widget = bacon_cd_selection_new ();
+	widget = nautilus_burn_drive_selection_new ();
 	gtk_widget_show (widget);
 
 	return widget;
@@ -422,21 +446,29 @@ on_tpw_color_reset_clicked (GtkButton *button, Totem *totem)
 }
 
 static void
-audio_out_menu_changed (GtkOptionMenu *option_menu, Totem *totem)
+audio_out_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
 	BaconVideoWidgetAudioOutType audio_out;
-	audio_out = gtk_option_menu_get_history (GTK_OPTION_MENU (option_menu));
-	bacon_video_widget_set_audio_out_type (totem->bvw, audio_out);
+	gboolean need_restart;
+
+	audio_out = gtk_combo_box_get_active (combobox);
+	need_restart = bacon_video_widget_set_audio_out_type (totem->bvw, audio_out);
+	if (need_restart != FALSE) {
+		totem_action_info (_("The change of audio output type will "
+					"only take effect when Totem is "
+					"restarted."),
+				totem);
+	}
+
 }
 
 void
 totem_setup_preferences (Totem *totem)
 {
 	GtkWidget *item, *menu;
-	const char *mediadev;
 	gboolean show_visuals, auto_resize, is_local, deinterlace;
-	int connection_speed, i, found;
-	char *path, *visual;
+	int connection_speed, i;
+	char *path, *visual, *mediadev;
 	GList *list, *l;
 	BaconVideoWidgetAudioOutType audio_out;
 
@@ -444,7 +476,7 @@ totem_setup_preferences (Totem *totem)
 
 	is_local = totem_display_is_local ();
 
-	gconf_client_add_dir (totem->gc, "/apps/totem",
+	gconf_client_add_dir (totem->gc, GCONF_PREFIX,
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/auto_resize",
 			(GConfClientNotifyFunc) auto_resize_changed_cb,
@@ -455,13 +487,21 @@ totem_setup_preferences (Totem *totem)
 	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/mediadev",
 			(GConfClientNotifyFunc) mediadev_changed_cb,
 			totem, NULL, NULL);
+	gconf_client_add_dir (totem->gc, "/desktop/gnome/lockdown",
+			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	gconf_client_notify_add (totem->gc,
+			"/desktop/gnome/lockdown/disable_save_to_disk",
+			(GConfClientNotifyFunc)
+			disable_save_to_disk_changed_cb,
+			totem, NULL, NULL);
 
-	totem->prefs = glade_xml_get_widget (totem->xml, "totem_preferences_window");
+	totem->prefs = glade_xml_get_widget (totem->xml,
+			"totem_preferences_window");
 
-	g_signal_connect (G_OBJECT (totem->prefs),
-			"response", G_CALLBACK (hide_prefs), (gpointer) totem);
+	g_signal_connect (G_OBJECT (totem->prefs), "response",
+			G_CALLBACK (gtk_widget_hide), NULL);
 	g_signal_connect (G_OBJECT (totem->prefs), "delete-event",
-			G_CALLBACK (hide_prefs), (gpointer) totem);
+			G_CALLBACK (gtk_widget_hide), NULL);
 
 	/* Auto-resize */
 	auto_resize = gconf_client_get_bool (totem->gc,
@@ -475,13 +515,14 @@ totem_setup_preferences (Totem *totem)
 
 	/* Media device */
 	item = glade_xml_get_widget (totem->xml, "tpw_device_combo");
-	mediadev = gconf_client_get_string
-		(totem->gc, GCONF_PREFIX"/mediadev", NULL);
+	mediadev = g_strdup (gconf_client_get_string
+		(totem->gc, GCONF_PREFIX"/mediadev", NULL));
 	if (mediadev == NULL || (strcmp (mediadev, "") == 0)
 			|| (strcmp (mediadev, "auto") == 0))
 	{
-		mediadev = bacon_cd_selection_get_default_device
-			(BACON_CD_SELECTION (item));
+		mediadev = g_strdup
+			(nautilus_burn_drive_selection_get_default_device
+				     (NAUTILUS_BURN_DRIVE_SELECTION (item)));
 		gconf_client_set_string (totem->gc, GCONF_PREFIX"/mediadev",
 				mediadev, NULL);
 	}
@@ -491,15 +532,16 @@ totem_setup_preferences (Totem *totem)
 	g_signal_connect (G_OBJECT (item), "device-changed",
 			G_CALLBACK (on_combo_entry1_changed), totem);
 
-	bacon_cd_selection_set_device (BACON_CD_SELECTION (item), mediadev);
+	nautilus_burn_drive_selection_set_device
+		(NAUTILUS_BURN_DRIVE_SELECTION (item), mediadev);
+	g_free (mediadev);
 
 	/* Connection Speed */
 	connection_speed = bacon_video_widget_get_connection_speed (totem->bvw);
-	item = glade_xml_get_widget (totem->xml, "tpw_speed_optionmenu");
-	gtk_option_menu_set_history (GTK_OPTION_MENU (item),
-			connection_speed);
+	item = glade_xml_get_widget (totem->xml, "tpw_speed_combobox");
+	gtk_combo_box_set_active (GTK_COMBO_BOX (item), connection_speed);
 	g_signal_connect (item, "changed",
-			G_CALLBACK (option_menu_connection_changed), totem);
+			G_CALLBACK (connection_combobox_changed), totem);
 
 	/* Proprietary plugins */
 	item = glade_xml_get_widget (totem->xml, "tpw_plugins_button");
@@ -535,36 +577,33 @@ totem_setup_preferences (Totem *totem)
 	if (visual == NULL || strcmp (visual, "") == 0)
 		visual = g_strdup ("goom");
 
-	i = found = 0;
+	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_combobox");
+	g_signal_connect (G_OBJECT (item), "changed",
+			G_CALLBACK (visual_menu_changed), totem);
+
+	i = 0;
 	for (l = list; l != NULL; l = l->next)
 	{
 		const char *name = l->data;
 
-		item = gtk_menu_item_new_with_label (name);
-		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-		gtk_widget_show (item);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (item), name);
 
 		if (strcmp (name, visual) == 0)
-			found = i;
+			gtk_combo_box_set_active (GTK_COMBO_BOX (item), i);
 
 		i++;
 	}
+	g_free (visual);
 
 	/* Visualisation quality */
 	i = gconf_client_get_int (totem->gc,
 			GCONF_PREFIX"/visual_quality", NULL);
 	bacon_video_widget_set_visuals_quality (totem->bvw, i);
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_optionmenu");
-	gtk_option_menu_set_history (GTK_OPTION_MENU (item), i);
+	item = glade_xml_get_widget (totem->xml, "tpw_visuals_size_combobox");
+	gtk_combo_box_set_active (GTK_COMBO_BOX (item), i);
 	g_signal_connect (G_OBJECT (item), "changed",
 			G_CALLBACK (visual_quality_menu_changed), totem);
 
-	item = glade_xml_get_widget (totem->xml, "tpw_visuals_type_optionmenu");
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (item), menu);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (item), found);
-	g_signal_connect (G_OBJECT (item), "changed",
-			G_CALLBACK (visual_menu_changed), totem);
-
 	/* Brightness */
 	item = glade_xml_get_widget (totem->xml, "tpw_bright_scale");
 	i = bacon_video_widget_get_video_property (totem->bvw,
@@ -603,9 +642,9 @@ totem_setup_preferences (Totem *totem)
 			G_CALLBACK (on_tpw_color_reset_clicked), totem);
 
 	/* Sound output type */
-	item = glade_xml_get_widget (totem->xml, "tpw_sound_output_optionmenu");
+	item = glade_xml_get_widget (totem->xml, "tpw_sound_output_combobox");
 	audio_out = bacon_video_widget_get_audio_out_type (totem->bvw);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (item), audio_out);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (item), audio_out);
 	g_signal_connect (G_OBJECT (item), "changed",
 			G_CALLBACK (audio_out_menu_changed), totem);
 
@@ -628,6 +667,14 @@ totem_setup_preferences (Totem *totem)
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
 			gconf_client_get_bool (totem->gc,
 				GCONF_PREFIX"/window_on_top", NULL));
+
+	/* Save to disk Lockdown */
+	item = glade_xml_get_widget
+		(totem->xml, "tmw_take_screenshot_menu_item");
+	gtk_widget_set_sensitive (item,
+			!gconf_client_get_bool (totem->gc,
+				"/desktop/gnome/lockdown/disable_save_to_disk",
+				NULL));
 }
 
 void
@@ -704,4 +751,5 @@ totem_preferences_visuals_setup (Totem *totem)
 		visual = g_strdup ("goom");
 
 	bacon_video_widget_set_visuals (totem->bvw, visual);
+	g_free (visual);
 }
