@@ -1,3 +1,29 @@
+/* 
+ * Copyright (C) 2003,2004 Bastien Nocera <hadess@hadess.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ *
+ */
 
 #include "config.h"
 
@@ -5,18 +31,19 @@
 #include <gnome.h>
 #else
 #include <gtk/gtk.h>
+#include <glib/gi18n.h>
 #endif
 
 #include <popt.h>
 
 #include <string.h>
-#include <unistd.h>
+#include <stdlib.h>
 #include "bacon-video-widget.h"
-#include "video-utils.h"
 
 /* #define THUMB_DEBUG */
 
 #define MIN_LEN_FOR_SEEK 25000
+#define HALF_SECOND G_USEC_PER_SEC * .5
 
 gboolean finished = FALSE;
 
@@ -40,7 +67,7 @@ show_pixbuf (GdkPixbuf *pix)
 static GdkPixbuf *
 add_holes_to_pixbuf_small (GdkPixbuf *pixbuf, int width, int height)
 {
-	GdkPixbuf *holes, *tmp;
+	GdkPixbuf *holes, *tmp, *target;
 	char *filename;
 	int i;
 
@@ -56,21 +83,23 @@ add_holes_to_pixbuf_small (GdkPixbuf *pixbuf, int width, int height)
 
 	g_assert (gdk_pixbuf_get_has_alpha (pixbuf) == FALSE);
 	g_assert (gdk_pixbuf_get_has_alpha (holes) != FALSE);
-	tmp = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
+	target = gdk_pixbuf_add_alpha (pixbuf, FALSE, 0, 0, 0);
 
 	for (i = 0; i < height; i += gdk_pixbuf_get_height (holes))
 	{
-		gdk_pixbuf_composite (holes, tmp, 0, i,
+		gdk_pixbuf_composite (holes, target, 0, i,
 				MIN (width, gdk_pixbuf_get_width (holes)),
 				MIN (height-i, gdk_pixbuf_get_height (holes)),
 				0, i, 1, 1, GDK_INTERP_NEAREST, 255);
 	}
 
-	totem_pixbuf_mirror (holes);
+	tmp = gdk_pixbuf_flip (holes, FALSE);
+	gdk_pixbuf_unref (holes);
+	holes = tmp;
 
 	for (i = 0; i < height; i += gdk_pixbuf_get_height (holes))
 	{
-		gdk_pixbuf_composite (holes, tmp,
+		gdk_pixbuf_composite (holes, target,
 				width - gdk_pixbuf_get_width (holes), i,
 				MIN (width, gdk_pixbuf_get_width (holes)),
 				MIN (height-i, gdk_pixbuf_get_height (holes)),
@@ -80,7 +109,7 @@ add_holes_to_pixbuf_small (GdkPixbuf *pixbuf, int width, int height)
 
 	gdk_pixbuf_unref (holes);
 
-	return tmp;
+	return target;
 }
 
 static GdkPixbuf *
@@ -292,11 +321,6 @@ time_monitor (gpointer data)
 
 int main (int argc, char *argv[])
 {
-	static struct poptOption options[] = {
-		{NULL, '\0', POPT_ARG_INCLUDE_TABLE, NULL, 0,
-			N_("Backend options"), NULL},
-		{NULL, '\0', 0, NULL, 0} /* end the list */
-	};
 	GError *err = NULL;
 	BaconVideoWidget *bvw;
 	GdkPixbuf *pixbuf;
@@ -312,17 +336,12 @@ int main (int argc, char *argv[])
 	nice (20);
 
 	g_thread_init (NULL);
-
-	options[0].arg = bacon_video_widget_get_popt_table ();
-#ifndef HAVE_GTK_ONLY
-	gnome_program_init ("totem-video-thumbnailer", VERSION,
-			LIBGNOME_MODULE, argc, argv,
-			GNOME_PARAM_APP_DATADIR, DATADIR,
-			GNOME_PARAM_POPT_TABLE, options,
-			GNOME_PARAM_NONE);
-#else /* !HAVE_GTK_ONLY */
+#ifndef THUMB_DEBUG
+	g_type_init ();
+#else
 	gtk_init (&argc, &argv);
-#endif /* !HAVE_GTK_ONLY */
+#endif
+	bacon_video_widget_init_backend (&argc, &argv);
 
 	if (!strcmp (argv[1], "-s")) {
 		input = argv[3];
@@ -334,7 +353,7 @@ int main (int argc, char *argv[])
 		size = 128;
 	}
 
-	bvw = BACON_VIDEO_WIDGET (bacon_video_widget_new (-1, -1, TRUE, &err));
+	bvw = BACON_VIDEO_WIDGET (bacon_video_widget_new (-1, -1, BVW_USE_TYPE_CAPTURE, &err));
 	if (err != NULL)
 	{
 		g_print ("totem-video-thumbnailer couln't create the video "
@@ -382,8 +401,17 @@ int main (int argc, char *argv[])
 		exit (1);
 	}
 
-	/* A 3rd into the file */
-	length = bacon_video_widget_get_stream_length (bvw);
+	/* A 3rd into the file - multi-times = HACK for gst backend... */
+	i = 0;
+	do {
+		if (i != 0) {
+			g_usleep (HALF_SECOND);
+			g_main_iteration (FALSE);
+		}
+		length = bacon_video_widget_get_stream_length (bvw);
+		i++;
+	} while (length == 0 && i < 20);
+
 	if (length > MIN_LEN_FOR_SEEK)
 	{
 		if (bacon_video_widget_seek
@@ -409,13 +437,14 @@ int main (int argc, char *argv[])
 
 	/* 10 seconds! */
 	i = 0;
-	pixbuf = bacon_video_widget_get_current_frame (bvw);
-	while (pixbuf == NULL && i < 20)
-	{
-		usleep (500000);
+	do {
+		/* This is a hack for the gst backend because it resyncs
+		 * after a seekj asynchronously, and so a direct get_frame()
+		 * would still return the old frame. */
+		g_usleep (HALF_SECOND);
 		pixbuf = bacon_video_widget_get_current_frame (bvw);
 		i++;
-	}
+	} while (pixbuf == NULL && i < 20);
 
 	/* Cleanup */
 	bacon_video_widget_close (bvw);
