@@ -1,26 +1,35 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
-
-   video-dev.c: detection of video devices
-
-   Copyright (C) 2003 Bastien Nocera
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the
-   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
-
-   Authors: Bastien Nocera <hadess@hadess.net>
-*/
+ *
+ *  video-dev.c: detection of video devices
+ *
+ *  Copyright (C) 2003 Bastien Nocera
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License as
+ *  published by the Free Software Foundation; either version 2 of the
+ *  License, or (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public
+ *  License along with this program; if not, write to the
+ *  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ *
+ *  Authors: Bastien Nocera <hadess@hadess.net>
+ *
+ * The Totem project hereby grant permission for non-gpl compatible GStreamer
+ * plugins to be used and distributed together with GStreamer and Totem. This
+ * permission are above and beyond the permissions granted by the GPL license
+ * Totem is covered by.
+ *
+ * Monday 7th February 2005: Christian Schaller: Add excemption clause.
+ * See license_change file for details.
+ *
+ */
 
 #include "config.h"
 
@@ -41,26 +50,6 @@
 
 #ifdef __linux__
 
-#ifdef USE_STABLE_LIBGLIB
-static gboolean
-g_str_has_prefix (gchar *haystack, gchar *needle)
-{
-	if (haystack == NULL && needle == NULL) {
-		return TRUE;
-	}
-
-	if (haystack == NULL || needle == NULL) {
-		return FALSE;
-	}
-
-	if (strncmp (haystack, needle, strlen (needle)) == 0) {
-		return TRUE;
-	}
-
-	return FALSE;
-}
-#endif /* USE_STABLE_LIBGLIB */
-
 static char **
 read_lines (char *filename)
 {
